@@ -63,22 +63,29 @@ def convert_units(model_file, units, scale, output_file):
 @edit.command('solve-adjacency')
 @click.argument('model-file', type=click.Path(
     exists=True, file_okay=True, dir_okay=False, resolve_path=True))
-@click.option('--wall/--air-boundary', ' /-ab', help='Flag to note whether the '
-              'wall adjacencies should be of the air boundary face type.',
-              default=True, show_default=True)
-@click.option('--surface/--adiabatic', ' /-a', help='Flag to note whether the '
-              'adjacencies should be surface or adiabatic.',
-              default=True, show_default=True)
+@click.option('--no-merge/--merge-coplanar', ' /-m', help='Flag to note whether '
+              'coplanar Faces of the Rooms should be merged before proceeding with '
+              'the rest of the adjacency solving. This is particularly helpful when '
+              'used with the --intersect option since it will ensure the Room geometry '
+              'is relatively clean before the intersection and adjacency solving '
+              'occurs.', default=True, show_default=True)
 @click.option('--no-intersect/--intersect', ' /-i', help='Flag to note whether the '
               'Faces of the Rooms should be intersected with one another before '
               'the adjacencies are solved.', default=True, show_default=True)
 @click.option('--no-overwrite/--overwrite', ' /-ow', help='Flag to note whether existing'
               ' Surface boundary conditions should be overwritten.',
               default=True, show_default=True)
+@click.option('--wall/--air-boundary', ' /-ab', help='Flag to note whether the '
+              'wall adjacencies should be of the air boundary face type.',
+              default=True, show_default=True)
+@click.option('--surface/--adiabatic', ' /-a', help='Flag to note whether the '
+              'adjacencies should be surface or adiabatic.',
+              default=True, show_default=True)
 @click.option('--output-file', '-f', help='Optional file to output the Model JSON string'
               ' with solved adjacency. By default it will be printed out to stdout',
               type=click.File('w'), default='-')
-def solve_adjacency(model_file, wall, surface, no_intersect, no_overwrite, output_file):
+def solve_adjacency(model_file, no_merge, no_intersect, no_overwrite,
+                    wall, surface, output_file):
     """Solve adjacency between Rooms of a Model file.
 
     \b
@@ -90,33 +97,15 @@ def solve_adjacency(model_file, wall, surface, no_intersect, no_overwrite, outpu
         parsed_model = Model.from_file(model_file)
         assert parsed_model.tolerance != 0, \
             'Model must have a non-zero tolerance to use solve-adjacency.'
-        tol, ang_tol = parsed_model.tolerance, parsed_model.angle_tolerance
-
-         # intersect adjacencies if requested
-        if not no_intersect:
-            Room.intersect_adjacency(parsed_model.rooms, tol, ang_tol)
 
         # solve adjacency
-        if no_overwrite:  # only assign new adjacencies
-            adj_info = Room.solve_adjacency(parsed_model.rooms, tol)
-        else:  # overwrite existing Surface BC
-            adj_faces = Room.find_adjacency(parsed_model.rooms, tol)
-            for face_pair in adj_faces:
-                face_pair[0].set_adjacency(face_pair[1])
-            adj_info = {'adjacent_faces': adj_faces}
-
-        # try to assign the air boundary face type
-        if not wall:
-            for face_pair in adj_info['adjacent_faces']:
-                if isinstance(face_pair[0].type, Wall):
-                    face_pair[0].type = face_types.air_boundary
-                    face_pair[1].type = face_types.air_boundary
-
-        # try to assign the adiabatic boundary condition
-        if not surface and ad_bc:
-            for face_pair in adj_info['adjacent_faces']:
-                face_pair[0].boundary_condition = ad_bc
-                face_pair[1].boundary_condition = ad_bc
+        merge_coplanar = not no_merge
+        intersect = not no_intersect
+        overwrite = not no_overwrite
+        air_boundary = not wall
+        adiabatic = not surface
+        parsed_model.solve_adjacency(
+            merge_coplanar, intersect, overwrite, air_boundary, adiabatic)
 
         # write the new model out to the file or stdout
         output_file.write(json.dumps(parsed_model.to_dict()))
@@ -513,3 +502,58 @@ def louvers_by_spacing(model_file, spacing, depth, angle, offset, horizontal,
         sys.exit(1)
     else:
         sys.exit(0)
+
+
+@edit.command('reset-resource-ids')
+@click.argument('model-file', type=click.Path(
+    exists=True, file_okay=True, dir_okay=False, resolve_path=True))
+@click.option(
+    '--by-name/--by-name-and-uuid', ' /-uuid', help='Flag to note whether '
+    'newly-generated resource object IDs should be derived only from a '
+    'cleaned display_name or whether this new ID should also have a unique '
+    'set of 8 characters appended to it to guarantee uniqueness.', default=True
+)
+@click.option(
+    '--output-file', '-f', help='Optional hbjson file to output the JSON '
+    'string of the converted model. By default this will be printed out to '
+    'stdout', type=click.File('w'), default='-', show_default=True
+)
+def reset_resource_ids(model_file, by_name, output_file):
+    """Reset the identifiers of all resource objects in a Model file.
+
+    This will reset the identifiers of all resources of all extensions and
+    is useful when human-readable names are needed when the model is
+    exported to simulation engines.
+
+    \b
+    Args:
+        model_file: Full path to a Honeybee Model (HBJSON) file.
+    """
+    try:
+        # load the model file and separately load up the resource objects
+        if sys.version_info < (3, 0):
+            with open(model_file) as inf:
+                data = json.load(inf)
+        else:
+            with open(model_file, encoding='utf-8') as inf:
+                data = json.load(inf)
+        model = Model.from_dict(data)
+        # reset the identifiers of resources in the dictionary
+        add_uuid = not by_name
+        for atr in model.properties._extension_attributes:
+            var = getattr(model.properties, atr)
+            if not hasattr(var, 'reset_resource_ids_in_dict'):
+                continue
+            try:
+                data = var.reset_resource_ids_in_dict(data, add_uuid)
+            except Exception as e:
+                import traceback
+                traceback.print_exc()
+                raise Exception('Failed to reset resource IDs for {}: {}'.format(var, e))
+        # write the dictionary into a JSON
+        output_file.write(json.dumps(data))
+    except Exception as e:
+        _logger.exception('Resetting resource identifiers failed.\n{}'.format(e))
+        sys.exit(1)
+    else:
+        sys.exit(0)
