@@ -18,6 +18,10 @@ def validate():
 @validate.command('model')
 @click.argument('model-json', type=click.Path(
     exists=True, file_okay=True, dir_okay=False, resolve_path=True))
+@click.option(
+    '--check-all/--room-overlaps', ' /-ro', help='Flag to note whether the output '
+    'validation report should validate all possible issues with the model or only '
+    'the Room collisions should be checked.', default=True, show_default=True)
 @click.option(
     '--plain-text/--json', ' /-j', help='Flag to note whether the output validation '
     'report should be formatted as a JSON object instead of plain text. If set to JSON, '
@@ -33,7 +37,7 @@ def validate():
     '--output-file', '-f', help='Optional file to output the full report '
     'of the validation. By default it will be printed out to stdout',
     type=click.File('w'), default='-')
-def validate_model(model_json, plain_text, output_file):
+def validate_model(model_json, check_all, plain_text, output_file):
     """Validate all properties of a Model file against the Honeybee schema.
 
     This includes checking basic compliance with the 5 rules of honeybee geometry
@@ -59,14 +63,19 @@ def validate_model(model_json, plain_text, output_file):
     try:
         if plain_text:
             # re-serialize the Model to make sure no errors are found
+            c_ver = folders.honeybee_core_version_str
+            s_ver = folders.honeybee_schema_version_str
             click.echo(
-                'Validating Model using honeybee-core=={} and honeybee-schema=={}'.format(
-                    folders.honeybee_core_version_str, folders.honeybee_schema_version_str
-                ))
+                'Validating Model using honeybee-core=={} and '
+                'honeybee-schema=={}'.format(c_ver, s_ver)
+            )
             parsed_model = Model.from_hbjson(model_json)
             click.echo('Re-serialization passed.')
             # perform several other checks for geometry rules and others
-            report = parsed_model.check_all(raise_exception=False, detailed=False)
+            if check_all:
+                report = parsed_model.check_all(raise_exception=False, detailed=False)
+            else:
+                report = parsed_model.check_room_volume_collisions(raise_exception=False)
             click.echo('Model checks completed.')
             # check the report and write the summary of errors
             if report == '':
@@ -77,14 +86,19 @@ def validate_model(model_json, plain_text, output_file):
         else:
             out_dict = {
                 'type': 'ValidationReport',
-                'honeybee_core': folders.honeybee_core_version_str,
-                'honeybee_schema': folders.honeybee_schema_version_str
+                'app_name': 'Honeybee',
+                'app_version': folders.honeybee_core_version_str,
+                'schema_version': folders.honeybee_schema_version_str
             }
             try:
                 parsed_model = Model.from_hbjson(model_json)
                 out_dict['fatal_error'] = ''
-                out_dict['errors'] = \
-                    parsed_model.check_all(raise_exception=False, detailed=True)
+                if check_all:
+                    errors = parsed_model.check_all(raise_exception=False, detailed=True)
+                else:
+                    errors = parsed_model.check_room_volume_collisions(
+                        raise_exception=False, detailed=True)
+                out_dict['errors'] = errors
                 out_dict['valid'] = True if len(out_dict['errors']) == 0 else False
             except Exception as e:
                 out_dict['fatal_error'] = str(e)
