@@ -307,7 +307,7 @@ class Door(_BaseWithShade):
         return orient_text[0]
 
     def add_prefix(self, prefix):
-        """Change the identifier of this object and all child objects by inserting a prefix.
+        """Change the identifier of this object and child objects by inserting a prefix.
 
         This is particularly useful in workflows where you duplicate and edit
         a starting object and then want to combine it with the original object
@@ -484,9 +484,17 @@ class Door(_BaseWithShade):
         Returns:
             True if geometrically equivalent. False if not geometrically equivalent.
         """
+        meta_1 = (self.display_name, self.is_glass, self.boundary_condition)
+        meta_2 = (door.display_name, door.is_glass, door.boundary_condition)
+        if meta_1 != meta_2:
+            return False
         if abs(self.area - door.area) > tolerance * self.area:
             return False
-        return self.geometry.is_centered_adjacent(door.geometry, tolerance)
+        if not self.geometry.is_centered_adjacent(door.geometry, tolerance):
+            return False
+        if not self._are_shades_equivalent(door, tolerance):
+            return False
+        return True
 
     def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
         """Check whether all of the Door's vertices lie within the same plane.
@@ -507,9 +515,15 @@ class Door(_BaseWithShade):
             self.geometry.check_planar(tolerance, raise_exception=True)
         except ValueError as e:
             msg = 'Door "{}" is not planar.\n{}'.format(self.full_id, e)
-            return self._validation_message(
+            full_msg = self._validation_message(
                 msg, raise_exception, detailed, '000101',
                 error_type='Non-Planar Geometry')
+            if detailed:  # add the out-of-plane points to helper_geometry
+                help_pts = [
+                    p.to_dict() for p in self.geometry.non_planar_vertices(tolerance)
+                ]
+                full_msg[0]['helper_geometry'] = help_pts
+            return full_msg
         return [] if detailed else ''
 
     def check_self_intersecting(self, tolerance=0.01, raise_exception=True,
@@ -534,39 +548,18 @@ class Door(_BaseWithShade):
         if self.geometry.is_self_intersecting:
             msg = 'Door "{}" has self-intersecting edges.'.format(self.full_id)
             try:  # see if it is self-intersecting because of a duplicate vertex
-                new_geo = self.geometry.remove_colinear_vertices(tolerance)
+                new_geo = self.geometry.remove_duplicate_vertices(tolerance)
                 if not new_geo.is_self_intersecting:
-                    return ''  # removing the duplicate vertex makes it self-intersecting
+                    return [] if detailed else ''  # valid with removed dup vertex
             except AssertionError:
-                pass  # zero area face; treat it as self-intersecting
-            return self._validation_message(
+                return [] if detailed else ''  # degenerate geometry
+            full_msg = self._validation_message(
                 msg, raise_exception, detailed, '000102',
                 error_type='Self-Intersecting Geometry')
-        return [] if detailed else ''
-
-    def check_non_zero(self, tolerance=0.0001, raise_exception=True, detailed=False):
-        """Check whether the area of the Door is above a certain "zero" tolerance.
-
-        Args:
-            tolerance: The minimum acceptable area of the object. Default is 0.0001,
-                which is equal to 1 cm2 when model units are meters. This is just
-                above the smallest size that OpenStudio will accept.
-            raise_exception: If True, a ValueError will be raised if the object
-                area is below the tolerance. Default: True.
-            detailed: Boolean for whether the returned object is a detailed list of
-                dicts with error info or a string with a message. (Default: False).
-
-        Returns:
-            A string with the message or a list with a dictionary if detailed is True.
-        """
-        if self.area < tolerance:
-            msg = 'Door "{}" geometry is too small. Area must be at least {}. ' \
-                'Got {}.'.format(self.full_id, tolerance, self.area)
-            if raise_exception:
-                raise ValueError(msg)
-            return self._validation_message(
-                msg, raise_exception, detailed, '000103',
-                error_type='Zero-Area Geometry')
+            if detailed:  # add the self-intersection points to helper_geometry
+                help_pts = [p.to_dict() for p in self.geometry.self_intersection_points]
+                full_msg[0]['helper_geometry'] = help_pts
+            return full_msg
         return [] if detailed else ''
 
     def display_dict(self):
