@@ -3,16 +3,14 @@
 from __future__ import division
 import math
 
-from ladybug_geometry.geometry2d.pointvector import Point2D, Vector2D
-from ladybug_geometry.geometry3d.pointvector import Point3D
-from ladybug_geometry.geometry3d.plane import Plane
-from ladybug_geometry.geometry3d.face import Face3D
+from ladybug_geometry.geometry2d import Vector2D, Point2D, Polygon2D, Mesh2D
+from ladybug_geometry.geometry3d import Vector3D, Point3D, Plane, Face3D
 from ladybug.color import Color
 
 from ._basewithshade import _BaseWithShade
 from .typing import clean_string, invalid_dict_error
 from .properties import FaceProperties
-from .facetype import face_types, get_type_from_normal, AirBoundary
+from .facetype import face_types, get_type_from_normal, AirBoundary, Floor, RoofCeiling
 from .boundarycondition import boundary_conditions, get_bc_from_position, \
     _BoundaryCondition, Outdoors, Surface, Ground
 from .shade import Shade
@@ -271,7 +269,7 @@ class Face(_BaseWithShade):
 
     @property
     def punched_geometry(self):
-        """Get a ladybug_geometry Face3D object with holes cut in it for apertures and doors.
+        """Get a Face3D object with holes cut in it for apertures and doors.
         """
         if self._punched_geometry is None:
             _sub_faces = tuple(sub_f.geometry for sub_f in self._apertures + self._doors)
@@ -313,7 +311,7 @@ class Face(_BaseWithShade):
 
     @property
     def normal(self):
-        """Get a ladybug_geometry Vector3D for the direction in which the face is pointing.
+        """Get a Vector3D for the direction in which the face is pointing.
         """
         return self._geometry.normal
 
@@ -427,7 +425,7 @@ class Face(_BaseWithShade):
         return orient_text[0]
 
     def add_prefix(self, prefix):
-        """Change the identifier of this object and all child objects by inserting a prefix.
+        """Change the identifier of this object and child objects by inserting a prefix.
 
         This is particularly useful in workflows where you duplicate and edit
         a starting object and then want to combine it with the original object
@@ -524,6 +522,11 @@ class Face(_BaseWithShade):
         for door in doors:
             self.add_door(door)
 
+    def replace_apertures(self, apertures):
+        """Replace all sub-faces assigned to this Face with a new list of Apertures."""
+        self.remove_sub_faces()
+        self.add_apertures(apertures)
+
     def set_adjacency(self, other_face, tolerance=0.01):
         """Set this face adjacent to another and set the other face adjacent to this one.
 
@@ -601,6 +604,286 @@ class Face(_BaseWithShade):
 
         return adj_info
 
+    def rectangularize_apertures(
+            self, subdivision_distance=None, max_separation=None,
+            merge_all=False, tolerance=0.01, angle_tolerance=1.0):
+        """Convert all Apertures on this Face to be rectangular.
+
+        This is useful when exporting to simulation engines that only accept
+        rectangular window geometry. This method will always result ing Rooms where
+        all Apertures are rectangular. However, if the subdivision_distance is not
+        set, some Apertures may extend past the parent Face or may collide with
+        one another.
+
+        Args:
+            subdivision_distance: A number for the resolution at which the
+                non-rectangular Apertures will be subdivided into smaller
+                rectangular units. Specifying a number here ensures that the
+                resulting rectangular Apertures do not extend past the parent
+                Face or collide with one another. If None, all non-rectangular
+                Apertures will be rectangularized by taking the bounding rectangle
+                around the Aperture. (Default: None).
+            max_separation: A number for the maximum distance between non-rectangular
+                Apertures at which point the Apertures will be merged into a single
+                rectangular geometry. This is often helpful when there are several
+                triangular Apertures that together make a rectangle when they are
+                merged across their frames. In such cases, this max_separation
+                should be set to a value that is slightly larger than the window frame.
+                If None, no merging of Apertures will happen before they are
+                converted to rectangles. (Default: None).
+            merge_all: Boolean to note whether all apertures should be merged before
+                they are rectangularized. If False, only non-rectangular apertures
+                will be merged before rectangularization. Note that this argument
+                has no effect when the max_separation is None. (Default: False).
+            tolerance: The maximum difference between point values for them to be
+                considered equivalent. (Default: 0.01, suitable for objects in meters).
+            angle_tolerance: The max angle in degrees that the corners of the
+                rectangle can differ from a right angle before it is not
+                considered a rectangle. (Default: 1).
+
+        Returns:
+            True if the Apertures were changed. False if they were unchanged.
+        """
+        # sort the rectangular and non-rectangular apertures
+        apertures = self._apertures
+        if len(apertures) == 0:
+            return False
+        tol, ang_tol = tolerance, math.radians(angle_tolerance)
+        rect_aps, non_rect_aps, non_rect_geos = [], [], []
+        for aperture in apertures:
+            try:
+                clean_geo = aperture.geometry.remove_colinear_vertices(tol)
+            except AssertionError:  # degenerate Aperture to be ignored
+                continue
+            if max_separation is None or not merge_all:
+                if clean_geo.polygon2d.is_rectangle(ang_tol):
+                    rect_aps.append(aperture)
+                else:
+                    non_rect_aps.append(aperture)
+                    non_rect_geos.append(clean_geo)
+            else:
+                non_rect_aps.append(aperture)
+                non_rect_geos.append(clean_geo)
+        if not non_rect_geos:  # nothing to be rectangularized
+            return False
+
+        # reset boundary conditions to outdoors so new apertures can be added
+        if not isinstance(self.boundary_condition, Outdoors):
+            self.boundary_condition = boundary_conditions.outdoors
+            for ap in rect_aps:
+                ap.boundary_condition = boundary_conditions.outdoors
+        edits_occurred = False
+
+        # try to merge the non-rectangular apertures if a max_separation is specified
+        ref_plane = self._reference_plane(ang_tol)
+        if max_separation is not None:
+            if merge_all or (not merge_all and len(non_rect_geos) > 1):
+                edits_occurred = True
+                if max_separation <= tol:  #  just join the Apertures at the tolerance
+                    non_rect_geos = Face3D.join_coplanar_faces(non_rect_geos, tol)
+                else:  # join the Apertures using the max_separation
+                    # get polygons for the faces that all lie within the same plane
+                    face_polys = []
+                    for fg in non_rect_geos:
+                        verts2d = tuple(ref_plane.xyz_to_xy(_v) for _v in fg.boundary)
+                        face_polys.append(Polygon2D(verts2d))
+                        if fg.has_holes:
+                            for hole in fg.holes:
+                                verts2d = tuple(ref_plane.xyz_to_xy(_v) for _v in hole)
+                                face_polys.append(Polygon2D(verts2d))
+                    # get the joined boundaries around the Polygon2D
+                    joined_bounds = Polygon2D.gap_crossing_boundary(
+                        face_polys, max_separation, tolerance)
+                    # convert the boundary polygons back to Face3D
+                    if len(joined_bounds) == 1:  # can be represented with a single Face3D
+                        verts3d = tuple(ref_plane.xy_to_xyz(_v) for _v in joined_bounds[0])
+                        non_rect_geos = [Face3D(verts3d, plane=ref_plane)]
+                    else:  # need to separate holes from distinct Face3Ds
+                        bound_faces = []
+                        for poly in joined_bounds:
+                            verts3d = tuple(ref_plane.xy_to_xyz(_v) for _v in poly)
+                            bound_faces.append(Face3D(verts3d, plane=ref_plane))
+                        non_rect_geos = Face3D.merge_faces_to_holes(bound_faces, tolerance)
+                clean_aps = []
+                for ap_geo in non_rect_geos:
+                    try:
+                        clean_aps.append(ap_geo.remove_colinear_vertices(tol))
+                    except AssertionError:  # degenerate Aperture to be ignored
+                        continue
+                non_rect_geos = clean_aps
+
+        # convert the remaining Aperture geometries to rectangles
+        if subdivision_distance is None:  # just take the bounding rectangle
+            edits_occurred = True
+            # get the bounding rectangle around all of the geometries
+            ap_geos = []
+            for ap_geo in non_rect_geos:
+                if ap_geo.polygon2d.is_rectangle(ang_tol):
+                    ap_geos.append(ap_geo)  # catch rectangles found in merging
+                    continue
+                geo_2d = Polygon2D([ref_plane.xyz_to_xy(v) for v in ap_geo.vertices])
+                g_min, g_max = geo_2d.min, geo_2d.max
+                base, hgt = g_max.x - g_min.x, g_max.y - g_min.y
+                bound_poly = Polygon2D.from_rectangle(g_min, Vector2D(0, 1), base, hgt)
+                geo_3d = Face3D([ref_plane.xy_to_xyz(v) for v in bound_poly.vertices])
+                ap_geos.append(geo_3d)
+            non_rect_geos = ap_geos
+
+        # create Aperture objects from all of the merged geometries
+        if not edits_occurred:
+            new_aps = non_rect_aps
+        else:
+            new_aps = []
+            for i, ap_face in enumerate(non_rect_geos):
+                exist_ap = None
+                for old_ap in non_rect_aps:
+                    if old_ap.center.is_equivalent(ap_face.center, tolerance):
+                        exist_ap = old_ap
+                        break
+                if exist_ap is None:  # could not be matched; just make a new aperture
+                    new_ap = Aperture('{}_RectGlz{}'.format(self.identifier, i), ap_face)
+                else:
+                    new_ap = Aperture(exist_ap.identifier, ap_face,
+                                    is_operable=exist_ap.is_operable)
+                    new_ap.display_name = '{}_{}'.format(exist_ap.display_name, i)
+                new_aps.append(new_ap)
+        
+        # we can just add the apertures if there's no subdivision going on
+        if subdivision_distance is None:
+            # remove any Apertures that are overlapping
+            all_aps = rect_aps + new_aps
+            all_aps = self._remove_overlapping_sub_faces(all_aps, tolerance)
+            self.remove_apertures()
+            self.add_apertures(all_aps)
+            return True
+
+        # if distance is provided, subdivide the apertures into strips
+        new_ap_objs = []
+        for ap_obj in new_aps:
+            ap_geo = ap_obj.geometry
+            if ap_geo.polygon2d.is_rectangle(ang_tol):
+                new_ap_objs.append(ap_obj)  # catch rectangles found in merging
+                continue
+            # create a mesh grid over the Aperture in the reference plane
+            geo_2d = Polygon2D([ref_plane.xyz_to_xy(v) for v in ap_geo.vertices])
+            try:
+                grid = Mesh2D.from_polygon_grid(
+                    geo_2d, subdivision_distance, subdivision_distance, False)
+            except AssertionError:  # Aperture smaller than resolution; ignore
+                continue
+
+            # group face by y value. All the rows will be merged together
+            vertices = grid.vertices
+            groups = {}
+            last_y = vertices[grid.faces[0][0]].y
+            for i, face in enumerate(grid.faces):
+                min_2d = vertices[face[0]]
+                for xy in groups:
+                    if abs(min_2d.x - xy[0]) < tolerance and abs(min_2d.y - last_y) < tolerance:
+                        groups[(xy[0], start_y)].append(face)
+                        break
+                else:
+                    start_y = min_2d.y
+                    groups[(min_2d.x, start_y)] = [face]
+                last_y = vertices[face[3]].y
+
+            # get the max and min of each group
+            sorted_groups = []
+            for group in groups.values():
+                # find min_2d and max_2d for each group
+                min_2d = vertices[group[0][0]]
+                max_2d = vertices[group[-1][2]]
+                sorted_groups.append({'min': min_2d, 'max': max_2d})
+
+            def _get_last_row(groups, start=0):
+                """An internal function to return the index for the last row that can be
+                merged with the start row that is passed to this function.
+
+                This function compares the min and max x and y values for each row to see
+                if they can be merged into a rectangle.
+                """
+                for count, group in enumerate(groups[start:]):
+                    next_group = groups[count + start + 1]
+                    if abs(group['min'].y - next_group['min'].y) <= tolerance \
+                        and abs(group['max'].y - next_group['max'].y) <= tolerance \
+                            and abs(next_group['min'].x - group['max'].x) <= tolerance:
+                        continue
+                    else:
+                        return start + count
+
+                return start + count + 1
+
+            # merge the rows if they have the same number of grid cells
+            sorted_groups.sort(key=lambda x: x['min'].x)
+            merged_groups = []
+            start_row = 0
+            last_row = -1
+            while last_row < len(sorted_groups):
+                try:
+                    last_row = _get_last_row(sorted_groups, start=start_row)
+                except IndexError:
+                    merged_groups.append(
+                        {
+                            'min': sorted_groups[start_row]['min'],
+                            'max': sorted_groups[len(sorted_groups) - 1]['max']
+                        }
+                    )
+                    break
+                else:
+                    merged_groups.append(
+                        {
+                            'min': sorted_groups[start_row]['min'],
+                            'max': sorted_groups[last_row]['max']
+                        }
+                    )
+                    if last_row == start_row:
+                        # the row was not grouped with anything else
+                        start_row += 1
+                    else:
+                        start_row = last_row + 1
+
+            # convert the groups into rectangular strips
+            for i, group in enumerate(merged_groups):
+                min_2d = group['min']
+                max_2d = group['max']
+                base, hgt = max_2d.x - min_2d.x, max_2d.y - min_2d.y
+                bound_poly = Polygon2D.from_rectangle(min_2d, Vector2D(0, 1), base, hgt)
+                geo_3d = Face3D([ref_plane.xy_to_xyz(v) for v in bound_poly.vertices])
+                new_ap = Aperture(
+                    '{}_Glz{}'.format(ap_obj.identifier, i),
+                    geo_3d, is_operable=ap_obj.is_operable)
+                new_ap.display_name = '{}_{}'.format(ap_obj.display_name, i)
+                new_ap_objs.append(new_ap)
+
+        # replace the apertures with the new ones
+        self.remove_apertures()
+        self.add_apertures(rect_aps + new_ap_objs)
+        return True
+
+    def _reference_plane(self, angle_tolerance):
+        """Get a Plane for this Face geometry derived from the Face3D plane.
+        
+        This will be oriented with the plane Y-Axis either aligned with the
+        World Z or World Y, which is helpful in rectangularization.
+
+        Args:
+            angle_tolerance: The max angle in radians that Face normal can differ
+                from the World Z before the Face is treated as being in the
+                World XY plane.
+        """
+        parent_llc = self.geometry.lower_left_corner
+        rel_plane = self.geometry.plane
+        vertical = Vector3D(0, 0, 1)
+        vert_ang = rel_plane.n.angle(vertical)
+        if vert_ang <= angle_tolerance or vert_ang >= math.pi - angle_tolerance:
+            proj_x = Vector3D(1, 0, 0)
+        else:
+            proj_y = vertical.project(rel_plane.n)
+            proj_x = proj_y.rotate(rel_plane.n, math.pi / -2)
+
+        ref_plane = Plane(rel_plane.n, parent_llc, proj_x)
+        return ref_plane
+
     def apertures_by_ratio(self, ratio, tolerance=0.01):
         """Add apertures to this Face given a ratio of aperture area to face area.
 
@@ -661,7 +944,7 @@ class Face(_BaseWithShade):
                 ratio is too large for the height, the ratio will take precedence
                 and the sill_height will be smaller than this value.
             horizontal_separation: A number for the target separation between
-                individual aperture centerlines.  If this number is larger than
+                individual aperture center lines.  If this number is larger than
                 the parent rectangle base, only one aperture will be produced.
             vertical_separation: An optional number to create a single vertical
                 separation between top and bottom apertures. The default is
@@ -759,7 +1042,7 @@ class Face(_BaseWithShade):
                 is too large for the sill_height to fit within the rectangle,
                 the aperture_height will take precedence.
             horizontal_separation: A number for the target separation between
-                individual apertures centerlines.  If this number is larger than
+                individual apertures center lines.  If this number is larger than
                 the parent rectangle base, only one aperture will be produced.
             tolerance: The maximum difference between point values for them to be
                 considered a part of a rectangle. Default: 0.01, suitable for
@@ -830,7 +1113,8 @@ class Face(_BaseWithShade):
             return
         self._acceptable_sub_face_check(Aperture)
         # Generate the aperture geometry
-        face_plane = Plane(self._geometry.plane.n, self._geometry.min)
+        origin = self._geometry.lower_left_counter_clockwise_vertices[0]
+        face_plane = Plane(self._geometry.plane.n, origin)
         if face_plane.y.z < 0:
             face_plane = face_plane.rotate(face_plane.n, math.pi, face_plane.o)
         center2d = face_plane.xyz_to_xy(self._geometry.center)
@@ -1125,6 +1409,10 @@ class Face(_BaseWithShade):
         Returns:
             True if geometrically equivalent. False if not geometrically equivalent.
         """
+        meta_1 = (self.display_name, self.type, self.boundary_condition)
+        meta_2 = (face.display_name, face.type, face.boundary_condition)
+        if meta_1 != meta_2:
+            return False
         if abs(self.area - face.area) > tolerance * self.area:
             return False
         if not self.geometry.is_centered_adjacent(face.geometry, tolerance):
@@ -1139,6 +1427,8 @@ class Face(_BaseWithShade):
         for dr1, dr2 in zip(self._doors, face._doors):
             if not dr1.is_geo_equivalent(dr2, tolerance):
                 return False
+        if not self._are_shades_equivalent(face, tolerance):
+            return False
         return True
 
     def check_sub_faces_valid(self, tolerance=0.01, angle_tolerance=1,
@@ -1245,10 +1535,14 @@ class Face(_BaseWithShade):
             raise ValueError(full_msg)
         return full_msg
 
-    def check_sub_faces_overlapping(self, raise_exception=True, detailed=False):
+    def check_sub_faces_overlapping(
+            self, tolerance=0.01, raise_exception=True, detailed=False):
         """Check that this Face's sub-faces do not overlap with one another.
 
         Args:
+            tolerance: The minimum distance that two sub-faces must overlap in order
+                for them to be considered overlapping and invalid. (Default: 0.01,
+                suitable for objects in meters).
             raise_exception: Boolean to note whether a ValueError should be raised
                 if a sub-faces overlap with one another.
             detailed: Boolean for whether the returned object is a detailed list of
@@ -1257,13 +1551,68 @@ class Face(_BaseWithShade):
         Returns:
             A string with the message or a list with dictionaries if detailed is True.
         """
-        sub_f_area = sum(sf.area for sf in self.sub_faces)
-        if sub_f_area > self.area:
-            msg = 'Face "{}" contains Apertures and/or ' \
+        sub_faces = self.sub_faces
+        if len(sub_faces) == 0:
+            return [] if detailed else ''
+        sf_groups = self._group_sub_faces_by_overlap(sub_faces, tolerance)
+        if not all(len(g) == 1 for g in sf_groups):
+            base_msg = 'Face "{}" contains Apertures and/or ' \
                 'Doors that overlap with each other.'.format(self.full_id)
-            return self._validation_message(
-                msg, raise_exception, detailed, '000105',
-                error_type='Overlapping Sub-Face Geometry')
+            if raise_exception:
+                raise ValueError(base_msg)
+            if not detailed:  # just give a message about the Face if not detailed
+                return base_msg
+            all_overlaps = []
+            for sf_group in sf_groups:
+                if len(sf_group) != 1:
+                    det_msg = 'The following sub-faces overlap with one another:' \
+                        '\n{}'.format('\n'.join([sf.full_id for sf in sf_group]))
+                    msg = '{}\n{}'.format(base_msg, det_msg)
+                    err_obj = self._validation_message_child(
+                        msg, sf_group[0], detailed, '000105',
+                        error_type='Overlapping Sub-Face Geometry')
+                    err_obj['element_type'] = 'SubFace'
+                    for ov_obj in sf_group[1:]:
+                        err_obj['element_id'].append(ov_obj.identifier)
+                        err_obj['element_name'].append(ov_obj.display_name)
+                        err_obj['parents'].append(err_obj['parents'][0])
+                    all_overlaps.append(err_obj)
+            return all_overlaps
+        return [] if detailed else ''
+
+    def check_upside_down(self, angle_tolerance=1, raise_exception=True, detailed=False):
+        """Check whether the face is pointing in the correct direction for the face type.
+
+        This method will only report Floors that are pointing upwards or RoofCeilings
+        that are pointed downwards. These cases are likely modeling errors and are in
+        danger of having their vertices flipped by EnergyPlus, causing them to
+        not see the sun.
+
+        Args:
+            angle_tolerance: The max angle in degrees that the Face normal can
+                differ from up or down before it is considered a case of a downward
+                pointing RoofCeiling or upward pointing Floor. Default: 1 degree.
+            raise_exception: Boolean to note whether an ValueError should be
+                raised if the Face is an an upward pointing Floor or a downward
+                pointing RoofCeiling.
+            detailed: Boolean for whether the returned object is a detailed list of
+                dicts with error info or a string with a message. (Default: False).
+
+        Returns:
+            A string with the message or a list with a dictionary if detailed is True.
+        """
+        msg = None
+        if isinstance(self.type, Floor) and self.altitude > 90 - angle_tolerance:
+            msg = 'Face "{}" is an upward-pointing Floor, which should be ' \
+                'changed to a RoofCeiling.'.format(self.full_id)
+        elif isinstance(self.type, RoofCeiling) and self.altitude < angle_tolerance - 90:
+            msg = 'Face "{}" is an downward-pointing RoofCeiling, which should be ' \
+                'changed to a Floor.'.format(self.full_id)
+        if msg:
+            full_msg = self._validation_message(
+                msg, raise_exception, detailed, '000109',
+                error_type='Upside Down Face')
+            return full_msg
         return [] if detailed else ''
 
     def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
@@ -1285,9 +1634,15 @@ class Face(_BaseWithShade):
             self.geometry.check_planar(tolerance, raise_exception=True)
         except ValueError as e:
             msg = 'Face "{}" is not planar.\n{}'.format(self.full_id, e)
-            return self._validation_message(
+            full_msg = self._validation_message(
                 msg, raise_exception, detailed, '000101',
                 error_type='Non-Planar Geometry')
+            if detailed:  # add the out-of-plane points to helper_geometry
+                help_pts = [
+                    p.to_dict() for p in self.geometry.non_planar_vertices(tolerance)
+                ]
+                full_msg[0]['helper_geometry'] = help_pts
+            return full_msg
         return [] if detailed else ''
 
     def check_self_intersecting(self, tolerance=0.01, raise_exception=True,
@@ -1312,37 +1667,18 @@ class Face(_BaseWithShade):
         if self.geometry.is_self_intersecting:
             msg = 'Face "{}" has self-intersecting edges.'.format(self.full_id)
             try:  # see if it is self-intersecting because of a duplicate vertex
-                new_geo = self.geometry.remove_colinear_vertices(tolerance)
+                new_geo = self.geometry.remove_duplicate_vertices(tolerance)
                 if not new_geo.is_self_intersecting:
                     return [] if detailed else ''  # valid with removed dup vertex
             except AssertionError:
-                pass  # zero area face; treat it as self-intersecting
-            return self._validation_message(
+                pass  # degenerate face; treat it as self-intersecting
+            full_msg = self._validation_message(
                 msg, raise_exception, detailed, '000102',
                 error_type='Self-Intersecting Geometry')
-        return [] if detailed else ''
-
-    def check_non_zero(self, tolerance=0.0001, raise_exception=True, detailed=False):
-        """Check whether the area of the Face is above a certain "zero" tolerance.
-
-        Args:
-            tolerance: The minimum acceptable area of the object. Default is 0.0001,
-                which is equal to 1 cm2 when model units are meters. This is just
-                above the smallest size that OpenStudio will accept.
-            raise_exception: If True, a ValueError will be raised if the object
-                area is below the tolerance. Default: True.
-            detailed: Boolean for whether the returned object is a detailed list of
-                dicts with error info or a string with a message. (Default: False).
-
-        Returns:
-            A string with the message or a list with a dictionary if detailed is True.
-        """
-        if self.area < tolerance:
-            msg = 'Face "{}" geometry is too small. Area must be at least {}. ' \
-                'Got {}.'.format(self.full_id, tolerance, self.area)
-            return self._validation_message(
-                msg, raise_exception, detailed, '000103',
-                error_type='Zero-Area Geometry')
+            if detailed:  # add the self-intersection points to helper_geometry
+                help_pts = [p.to_dict() for p in self.geometry.self_intersection_points]
+                full_msg[0]['helper_geometry'] = help_pts
+            return full_msg
         return [] if detailed else ''
 
     def display_dict(self):
@@ -1421,6 +1757,67 @@ class Face(_BaseWithShade):
             '{} cannot be added to AirBoundary Face "{}".'.format(
                 sub_face_type.__name__, self.full_id)
 
+    @staticmethod
+    def _remove_overlapping_sub_faces(sub_faces, tolerance):
+        """Get a list of Apertures and/or Doors with no overlaps.
+
+        Args:
+            sub_faces: A list of Apertures or Doors to be checked for overlapping.
+            tolerance: The minimum distance from the edge of a neighboring Face3D
+                at which a point is considered to overlap with that Face3D.
+
+        Returns:
+            A list of the input sub_faces with smaller overlapping geometries removed.
+        """
+        # group the sub-faces according to the overlaps with one another
+        grouped_sfs = Face._group_sub_faces_by_overlap(sub_faces, tolerance)
+        # build a list of sub-faces without any overlaps
+        clean_sub_faces = []
+        for sf_group in grouped_sfs:
+            if len(sf_group) == 1:
+                clean_sub_faces.append(sf_group[0])
+            else:  # take the subface with the largest area
+                sf_group.sort(key=lambda x: x.area, reverse=True)
+                clean_sub_faces.append(sf_group[0])
+        return clean_sub_faces
+
+    @staticmethod
+    def _group_sub_faces_by_overlap(sub_faces, tolerance):
+        """Group a Apertures and/or Doors depending on whether they overlap one another.
+
+        Args:
+            sub_faces: A list of Apertures or Doors to be checked for overlapping.
+            tolerance: The minimum distance from the edge of a neighboring Face3D
+                at which a point is considered to overlap with that Face3D.
+
+        Returns:
+            A list of lists where each sub-list represents a group of Apertures and/or
+            Doors that overlap with one another.
+        """
+        # sort the sub-faces by area
+        sub_faces = list(sorted(sub_faces, key=lambda x: x.area, reverse=True))
+        # create polygons for all of the faces
+        r_plane = sub_faces[0].geometry.plane
+        polygons = [Polygon2D([r_plane.xyz_to_xy(pt) for pt in face.vertices])
+                    for face in sub_faces]
+        # loop through the polygons and check to see if it overlaps with the others
+        grouped_polys, grouped_sfs = [[polygons[0]]], [[sub_faces[0]]]
+        for poly, face in zip(polygons[1:], sub_faces[1:]):
+            group_found = False
+            for poly_group, face_group in zip(grouped_polys, grouped_sfs):
+                for oth_poly in poly_group:
+                    if poly.polygon_relationship(oth_poly, tolerance) >= 0:
+                        poly_group.append(poly)
+                        face_group.append(face)
+                        group_found = True
+                        break
+                if group_found:
+                    break
+            if not group_found:  # the polygon does not overlap with any of the others
+                grouped_polys.append([poly])  # make a new group for the polygon
+                grouped_sfs.append([face])  # make a new group for the face
+        return grouped_sfs
+
     def __copy__(self):
         new_f = Face(self.identifier, self.geometry, self.type, self.boundary_condition)
         new_f._display_name = self._display_name
